yt.frontends.enzo.data_structures.EnzoHierarchy1D.find_particles_by_type — The yt Project 3.2-dev documentation

# yt.frontends.enzo.data_structures.EnzoHierarchy1D.find_particles_by_type

`EnzoHierarchy1D.` `find_particles_by_type`(ptype, max_num=None, additional_fields=None)

  Returns a structure of arrays with all of the particles’ positions, velocities, masses, types, IDs, and attributes for a particle type ptype for a maximum of max_num particles. If non-default particle fields are used, provide them in additional_fields.